@@ -3,22 +3,22 @@
 # for quick tests only, should not be depended upon for
 # proper examples of current api.
 
-use strict;
-use warnings;
+use strictures 1;
 use v5.10;
 use FindBin;
 use lib "$FindBin::Bin/../../lib";
-use Net::OAuth::LP::Models::Person;
 use Net::OAuth::LP::Models::Bug;
+use Net::OAuth::LP::Models::Person;
+use Net::OAuth::LP::Client;
 use Data::Dump qw(pp);
-use File::Spec::Functions;
-use JSON;
 
-pp(JSON->backend);
-my $p = Net::OAuth::LP::Models::Person->new;
-$p->staging(1);
-$p->find('~adam-stokes');
-pp($p->karma);
-pp(defined($p->karma));
+my $c = Net::OAuth::LP::Client->new;
+$c->staging(1);
+
+my $bug = Net::OAuth::LP::Models::Bug->new(c => $c);
+$bug->find('859600');
+my $newbug = $bug->tasks->entries->first(sub { $_->{bug_target_name} =~ /(Ubuntu)/ });
+pp($newbug);
+
 
 
