@@ -1,23 +1,25 @@
 package Net::OAuth::LP::Models;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
+use strictures 1;
 use Moo::Role;
 use Method::Signatures;
 
-with('Net::OAuth::LP::Client');
+has 'c' => (is => 'rw',);
 
 method find         { }
 method find_by_link { }
+method filter       { }
 
 method search ($path, $segments) {
-    my $query = $self->__query_from_hash($segments);
+    my $query = $self->c->__query_from_hash($segments);
     my $uri = join("?", $path, $query);
-    $self->get($uri);
+    $self->c->get($uri);
 }
 
 method resource ($resource_link) {
-    $self->get($resource_link);
+    $self->c->get($resource_link);
 }
 
 1;
@@ -32,6 +34,12 @@ Net::OAuth::LP::Models - Base class for models
 
 Base Model Role
 
+=head1 ATTRIBUTES
+
+=head2 B<c>
+
+Client attribute to perform authenticated requests.
+
 =head1 METHODS
 
 =head2 B<find>
